@@ -1,4 +1,4 @@
-from django.utils.safestring import mark_safe
+from django.utils.html import format_html
 
 
 class FormLabelModelAdminMixin:
@@ -25,5 +25,5 @@ class FormLabelModelAdminMixin:
                     request=request, obj=obj, model=self.model, form=form
                 )
                 if label:
-                    form.base_fields[form_label.field].label = mark_safe(label)
+                    form.base_fields[form_label.field].label = format_html(label)
         return form
