@@ -2,13 +2,15 @@ from django.db import models
 from django.db.models.deletion import PROTECT
 from edc_appointment.models import Appointment
 from edc_constants.choices import YES_NO
+from edc_crf.model_mixins import CrfModelMixin
 from edc_model.models import BaseUuidModel
+from edc_sites.models import SiteModelMixin
 from edc_utils import get_utcnow
 from edc_visit_schedule.model_mixins import OffScheduleModelMixin, OnScheduleModelMixin
-from edc_visit_tracking.model_mixins import VisitModelMixin, VisitTrackingCrfModelMixin
+from edc_visit_tracking.model_mixins import VisitModelMixin
 
 
-class SubjectVisit(VisitModelMixin, BaseUuidModel):
+class SubjectVisit(SiteModelMixin, VisitModelMixin, BaseUuidModel):
 
     subject_identifier = models.CharField(max_length=25)
 
@@ -17,7 +19,7 @@ class SubjectVisit(VisitModelMixin, BaseUuidModel):
     appointment = models.OneToOneField(Appointment, on_delete=PROTECT)
 
 
-class MyModel(VisitTrackingCrfModelMixin, BaseUuidModel):
+class MyModel(CrfModelMixin, BaseUuidModel):
 
     subject_visit = models.OneToOneField(SubjectVisit, on_delete=PROTECT)
 
@@ -28,11 +30,11 @@ class MyModel(VisitTrackingCrfModelMixin, BaseUuidModel):
     )
 
 
-class OnSchedule(OnScheduleModelMixin, BaseUuidModel):
+class OnSchedule(SiteModelMixin, OnScheduleModelMixin, BaseUuidModel):
     class Meta(OnScheduleModelMixin.Meta):
         pass
 
 
-class OffSchedule(OffScheduleModelMixin, BaseUuidModel):
+class OffSchedule(SiteModelMixin, OffScheduleModelMixin, BaseUuidModel):
     class Meta(OffScheduleModelMixin.Meta):
         pass
